.. Data Pipeline documentation master file, created by
   sphinx-quickstart on Mon Sep 16 14:15:25 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Data Pipeline documentation
===========================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   modules

   

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

